@@ -12,7 +12,7 @@ poscmp<-function(s,s2=NULL,rc=rep(FALSE,length=length(s2)),maxN=NULL,
                   memmu_proposal=0.1, memscale_proposal=0.15,
                   visibility=TRUE,
                   Np=0,
-                  samplesize=10,burnin=0,interval=1,burnintheta=500,burninbeta=20,
+                  samplesize=10,warmup=0,interval=1,warmuptheta=500,warmupbeta=20,
                   priorsizedistribution=c("beta","nbinom","pln","flat","supplied"),
                   mean.prior.size=NULL, sd.prior.size=NULL,
                   mode.prior.sample.proportion=NULL,
@@ -90,7 +90,7 @@ poscmp<-function(s,s2=NULL,rc=rep(FALSE,length=length(s2)),maxN=NULL,
               n2=as.integer(n2),
               n0=as.integer(n0),
               samplesize=as.integer(samplesize),
-              burnin=as.integer(burnin),
+              warmup=as.integer(warmup),
               interval=as.integer(interval),
               mu=as.double(mean.prior.visibility), df.mean.prior.visibility=as.double(df.mean.prior.visibility),
               sigma=as.double(sd.prior.visibility), df.sd.prior.visibility=as.double(df.sd.prior.visibility),
@@ -120,8 +120,8 @@ poscmp<-function(s,s2=NULL,rc=rep(FALSE,length=length(s2)),maxN=NULL,
               vsample2=integer(samplesize*n2),
               ppos=double(K),
               lpriorm=as.double(prior$lprior),
-              burnintheta=as.integer(burnintheta),
-              burninbeta=as.integer(burninbeta),
+              warmuptheta=as.integer(warmuptheta),
+              warmupbeta=as.integer(warmupbeta),
               verbose=as.integer(verbose), PACKAGE="sspse")
      }else{
       cat(sprintf("Using Capture-recapture non-measurement error model with K = %d.\n",K))
@@ -139,7 +139,7 @@ poscmp<-function(s,s2=NULL,rc=rep(FALSE,length=length(s2)),maxN=NULL,
               n2=as.integer(n2),
               n0=as.integer(n0),
               samplesize=as.integer(samplesize),
-              burnin=as.integer(burnin),
+              warmup=as.integer(warmup),
               interval=as.integer(interval),
               mu=as.double(mean.prior.visibility), df.mean.prior.visibility=as.double(df.mean.prior.visibility),
               sigma=as.double(sd.prior.visibility), df.sd.prior.visibility=as.double(df.sd.prior.visibility),
@@ -152,7 +152,7 @@ poscmp<-function(s,s2=NULL,rc=rep(FALSE,length=length(s2)),maxN=NULL,
               sample=double(samplesize*dimsample),
               ppos=double(K),
               lpriorm=as.double(prior$lprior),
-              burnintheta=as.integer(burnintheta),
+              warmuptheta=as.integer(warmuptheta),
               verbose=as.integer(verbose), PACKAGE="sspse")
      }
     }else{
@@ -164,7 +164,7 @@ poscmp<-function(s,s2=NULL,rc=rep(FALSE,length=length(s2)),maxN=NULL,
               K=as.integer(K),
               n=as.integer(n1),
               samplesize=as.integer(samplesize),
-              burnin=as.integer(burnin),
+              warmup=as.integer(warmup),
               interval=as.integer(interval),
               mu=as.double(mean.prior.visibility), df.mean.prior.visibility=as.double(df.mean.prior.visibility),
               sigma=as.double(sd.prior.visibility), df.sd.prior.visibility=as.double(df.sd.prior.visibility),
@@ -190,8 +190,8 @@ poscmp<-function(s,s2=NULL,rc=rep(FALSE,length=length(s2)),maxN=NULL,
               posu=double(K),
               posd=double(K),
               lpriorm=as.double(prior$lprior),
-              burnintheta=as.integer(burnintheta),
-              burninbeta=as.integer(burninbeta),
+              warmuptheta=as.integer(warmuptheta),
+              warmupbeta=as.integer(warmupbeta),
               verbose=as.integer(verbose), PACKAGE="sspse")
      }else{
       cat(sprintf("Using a non-measurement error model with K = %d.\n",K))
@@ -202,7 +202,7 @@ poscmp<-function(s,s2=NULL,rc=rep(FALSE,length=length(s2)),maxN=NULL,
               K=as.integer(K),
               n=as.integer(n1),
               samplesize=as.integer(samplesize),
-              burnin=as.integer(burnin),
+              warmup=as.integer(warmup),
               interval=as.integer(interval),
               mu=as.double(mean.prior.visibility), df.mean.prior.visibility=as.double(df.mean.prior.visibility),
               sigma=as.double(sd.prior.visibility), df.sd.prior.visibility=as.double(df.sd.prior.visibility),
@@ -215,7 +215,7 @@ poscmp<-function(s,s2=NULL,rc=rep(FALSE,length=length(s2)),maxN=NULL,
               sample=double(samplesize*dimsample),
               ppos=double(K),
               lpriorm=as.double(prior$lprior),
-              burnintheta=as.integer(burnintheta),
+              warmuptheta=as.integer(warmuptheta),
               verbose=as.integer(verbose), PACKAGE="sspse")
      }
     }
@@ -298,8 +298,8 @@ poscmp<-function(s,s2=NULL,rc=rep(FALSE,length=length(s2)),maxN=NULL,
     Cret$predictive.visibility<-Cret$posu
     Cret$predictive.degree<-Cret$posd
     Cret$ppos<-NULL
-    endrun <- burnin+interval*(samplesize-1)
-    attr(Cret$sample, "mcpar") <- c(burnin+1, endrun, interval)
+    endrun <- warmup+interval*(samplesize-1)
+    attr(Cret$sample, "mcpar") <- c(warmup+1, endrun, interval)
     attr(Cret$sample, "class") <- "mcmc"
     ### compute modes of posterior samples,Maximum A Posterior (MAP) values N, mu, sigma, visibility1
     Cret$MAP <- apply(Cret$sample,2,mode.density)
